<?php

namespace Drupal\Tests\helper\Kernel;

use Drupal\KernelTests\KernelTestBase;

/**
 * Tests the install profile helper.
 *
 * @coversDefaultClass \Drupal\helper\InstallProfile
 * @group helper
 */
class InstallProfileTest extends KernelTestBase {

  /**
   * {@inheritdoc}
   */
  public static $modules = [
    'system',
    'helper',
  ];

  /**
   * The install profile helper.
   *
   * @var \Drupal\helper\InstallProfile
   */
  protected $installProfile;

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();
    $this->installProfile = $this->container->get('helper.install_profile');
    $this->setInstallProfile('testing');
  }

  /**
   * Tests switching profiles.
   *
   * @covers ::switch
   */
  public function testSwitch() {
    $this->assertSame('testing', \Drupal::installProfile());
    $this->assertSame(SCHEMA_UNINSTALLED, drupal_get_installed_schema_version('minimal'));
    $this->assertSame(SCHEMA_UNINSTALLED, drupal_get_installed_schema_version('standard'));

    $this->installProfile->switch('minimal');
    $this->assertSame('minimal', \Drupal::installProfile());
    $this->assertSame(8000, drupal_get_installed_schema_version('minimal'));
    $this->assertSame(SCHEMA_UNINSTALLED, drupal_get_installed_schema_version('standard'));
    $this->assertSame(SCHEMA_UNINSTALLED, drupal_get_installed_schema_version('testing'));
  }

  /**
   * Tests switching to an invalid profile.
   *
   * @covers ::switch
   */
  public function testSwitchInvalidProfile() {
    $this->expectException(\InvalidArgumentException::class);
    $this->expectExceptionMessage('The install profile profile_does_not_exist does not exist.');
    $this->installProfile->switch('profile_does_not_exist');
  }

}
